hydrate

Function hydrate 

pub fn hydrate(
    source: &dyn AssetSource,
    hash: AssetHash,
) -> Result<Asset, AssetFault>
Read hash’s payload back and check it against the hash that named it.

Errors

AssetFault when the payload is not there, or is not the payload.