pub fn asset_entry(hash: AssetHash, format: AssetFormat) -> EntryExpand description
Where a payload of hash is filed, given the format that reads it.
pub fn asset_entry(hash: AssetHash, format: AssetFormat) -> EntryWhere a payload of hash is filed, given the format that reads it.