exported_stamp_in

Function exported_stamp_in 

pub fn exported_stamp_in(text: &str) -> Option<Stamp>
Whether text is a flattened document carrying a stamp — what a document that left home has and a hand-written one does not.