within

Function within 

fn within<'a>(dir: &str, key: &'a str) -> Option<&'a str>
The name dir holds key under, or None where key is not in it. The root holds everything with no separator left in it.