Native

Struct Native 

pub struct Native(PathBuf);
A container’s directory.

Tuple Fields

0: PathBuf

Implementations

Source

impl Native

pub fn at(root: impl Into<PathBuf>) -> Self

pub fn root(&self) -> &Path

fn path(&self, at: &Entry) -> PathBuf

fn holding(&self, at: &Entry) -> Result<PathBuf>

The directory an entry is written into, made if it is not there. A container whose revs/ somebody removed is repaired by the write that needs it.